<?php

namespace Bydedi\DebugBar\EventListener;

use Bydedi\DebugBar\DebugBarInterface;
use Bydedi\Http\Event\FilterResponseEvent;
use Bydedi\Http\HttpEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\Templating\EngineInterface;

class DebugBarListener implements EventSubscriberInterface
{

    /**
     * @var \Symfony\Component\Templating\EngineInterface
     */
    protected $engine;

    /**
     * @var \Bydedi\DebugBar\DebugBarInterface
     */
    protected $debugBar;

    public function __construct(EngineInterface $engine, DebugBarInterface $debugBar)
    {
        $this->engine = $engine;
        $this->debugBar = $debugBar;
    }

    public function onResponse(FilterResponseEvent $event)
    {

        if (getenv('APP_DEBUG') != 1) {
            return;
        }

        $response = $event->getResponse();
        $request = $event->getRequest();

        // do not capture redirects or modify XML HTTP Requests
        if ($request->isXmlHttpRequest()) {
            return;
        }

        $content = $response->getContent();
        $pos = strripos($content, '</body>');

        if (false === $pos) {
            return;
        }

        $content = substr($content, 0, $pos) . $this->debugBar->render() . substr($content, $pos);
        $response->setContent($content);
    }

    /**
     * @return array
     */
    public static function getSubscribedEvents()
    {
        return array(
            HttpEvents::RESPONSE => array('onResponse', -128),
        );
    }
}
